import { EVMAccountAddress, EVMContractAddress, BlockchainCommonErrors, OperatorGatewayContractError, PasskeyId, P256PublicKeyComponents, P256SignatureComponents, LayerZeroEndpointId, OperatorDomain, TokenAmount } from "@snickerdoodlelabs/objects";
import { ethers } from "ethers";
import { ResultAsync } from "neverthrow";
import { IEthersContractError } from "../implementations/BlockchainErrorMapper.js";
import { ERC7529Contract } from "../implementations/ERC7529Contract.js";
import { ContractOverrides, WrappedTransactionResponse, IOperatorGatewayContract } from "../interfaces/index.js";
import { P256VerificationData } from "../interfaces/objects/index.js";
export declare class OperatorGatewayContract extends ERC7529Contract<OperatorGatewayContractError> implements IOperatorGatewayContract {
    protected providerOrSigner: ethers.Provider | ethers.Signer;
    protected contractAddress: EVMContractAddress;
    constructor(providerOrSigner: ethers.Provider | ethers.Signer, contractAddress: EVMContractAddress);
    deployWallets(usernames: string[], p256Keys: P256PublicKeyComponents[][], evmAccounts: EVMContractAddress[][] | EVMAccountAddress[][], overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, OperatorGatewayContractError | BlockchainCommonErrors>;
    reserveWalletsOnDestinationChain(destinationLayerZeroEndpointId: LayerZeroEndpointId, usernames: string[], gas: bigint, nativeTokenFee: bigint, // Required fee calculated from the quote function to be sent with the transaction to pay for the LayerZero _lzReceive() call
    overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | OperatorGatewayContractError>;
    quoteAuthorizeOperatorGatewayOnDestinationChain(destinationLayerZeroEndpointId: LayerZeroEndpointId, domain: OperatorDomain, gas: bigint): ResultAsync<TokenAmount, OperatorGatewayContractError | BlockchainCommonErrors>;
    authorizeWalletOnDestinationChain(destinationLayerZeroEndpointId: LayerZeroEndpointId, username: string, gas: bigint, nativeTokenFee: bigint, // Required fee calculated from the quoteAuthorizeWalletOnDestinationChain function to be sent with the transaction to pay for the LayerZero _lzReceive() call
    overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | OperatorGatewayContractError>;
    addP256KeysWithP256Keys(evmAccounts: EVMContractAddress[] | EVMAccountAddress[], keyIds: PasskeyId[], p256VerificationDatas: P256VerificationData[], newP256Keys: P256PublicKeyComponents[], p256Signatures: P256SignatureComponents[], overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | OperatorGatewayContractError>;
    protected generateContractSpecificError(msg: string, e: IEthersContractError, transaction: ethers.Transaction | null): OperatorGatewayContractError;
}
//# sourceMappingURL=OperatorGatewayContract.d.ts.map